@@ -15,16 +15,24 @@ def html_to_df(page_source):
     colss = df.columns
     discard = [" TR"]
     df = df[~df[colss[0]].str.contains('|'.join(discard))]
+    discard = [" IL"]
+    df = df[~df[colss[0]].str.contains('|'.join(discard))]
 
-    for col in df.columns[1:]:
-        df[col] = df[col].astype(str).str.replace(" ", "")
-        df[col] = df[col].astype(str).str.replace("kr", "")
-        df[col] = df[col].astype(str).str.replace(u"\xa0", "")
-        df[col] = df[col].astype(str).str.replace(u"%", "")
-        df[col] = df[col].astype(str).str.replace(u",", ".")
-        df[col] = df[col].astype(str).str.replace("−", "-")
-        df[col] = df[col].astype(str).str.replace("—", "-")
-        df[col] = df[col].astype(float)
+    try:
+        for col in df.columns[1:]:
+            df[col] = df[col].astype(str).str.replace(" ", "")
+            df[col] = df[col].astype(str).str.replace("kr", "")
+            df[col] = df[col].astype(str).str.replace(u"\xa0", "")
+            df[col] = df[col].astype(str).str.replace(u"%", "")
+            df[col] = df[col].astype(str).str.replace(u",", ".")
+            df[col] = df[col].astype(str).str.replace("−", "-")
+            df[col] = df[col].astype(str).str.replace("—", "-")
+            df[col] = df[col].astype(float)
+    except Exception as e:
+        print(e)
+        print(col)
+        print(df.columns[1:])
+        print(df)
 
     df[df.columns[5]] = df.fillna(0)[df.columns[5]] + df.fillna(0)[df.columns[6]]
     df = df.drop([df.columns[6]], axis=1)
